use rand::Rng;
use rapier2d::{dynamics::RigidBodyHandle, geometry::ColliderHandle};

use galactica_content as content;

/// A single projectile in the world
#[derive(Debug)]
pub struct ProjectileWorldObject {
	/// This projectile's game data
	pub content: content::Projectile,

	/// The remaining lifetime of this projectile, in seconds
	pub lifetime: f32,

	/// The faction this projectile belongs to
	pub faction: content::FactionHandle,

	/// This projectile's rigidbody
	pub rigid_body: RigidBodyHandle,

	/// This projectile's collider
	pub collider: ColliderHandle,

	/// This projectile's size variation
	pub size_rng: f32,
}

impl ProjectileWorldObject {
	/// Create a new projectile
	pub fn new(
		content: content::Projectile, // TODO: use a handle
		rigid_body: RigidBodyHandle,
		faction: content::FactionHandle,
		collider: ColliderHandle,
	) -> Self {
		let mut rng = rand::thread_rng();
		let size_rng = content.size_rng;
		let lifetime = content.lifetime;
		ProjectileWorldObject {
			rigid_body,
			collider,
			content,
			lifetime,
			faction,
			size_rng: rng.gen_range(-size_rng..=size_rng),
		}
	}

	/// Process this projectile's state after `t` seconds
	pub fn tick(&mut self, t: f32) {
		self.lifetime -= t;
	}

	/// Has this projectile expired?
	pub fn is_expired(&self) -> bool {
		return self.lifetime < 0.0;
	}
}
